==> gammaray_2.0.1.orig.tar.xz: gammaray-2.0.1/plugins/widgetinspector/paintbufferviewer.cpp <==
/*
  paintbufferviewer.cpp

  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2012-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Volker Krause <volker.krause@kdab.com>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "paintbufferviewer.h"

#include "ui_paintbufferviewer.h"

#include "widgetinspectorinterface.h"
#include <common/objectbroker.h>

using namespace GammaRay;

PaintBufferViewer::PaintBufferViewer(QWidget *parent)
  : QDialog(parent)
  , ui(new Ui::PaintBufferViewer)
{
  ui->setupUi(this);

  ui->commandView->setModel(ObjectBroker::model("com.kdab.GammaRay.PaintBufferModel"));
  ui->commandView->setSelectionModel(ObjectBroker::selectionModel(ui->commandView->model()));

  ui->splitter->setStretchFactor(0, 0);
  ui->splitter->setStretchFactor(1, 1);

  connect(ObjectBroker::object<WidgetInspectorInterface*>(), SIGNAL(paintAnalyzed(QPixmap)),
          ui->replayWidget, SLOT(setPixmap(QPixmap)));
  connect(ui->zoomSlider, SIGNAL(valueChanged(int)), ui->replayWidget, SLOT(setZoomFactor(int)));
}

PaintBufferViewer::~PaintBufferViewer()
{
}

==> gammaray_2.4.0.orig.tar.xz: gammaray-2.4.0/plugins/widgetinspector/paintbufferviewer.cpp <==
/*
  paintbufferviewer.cpp

  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2012-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Volker Krause <volker.krause@kdab.com>

  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
  accordance with GammaRay Commercial License Agreement provided with the Software.

  Contact info@kdab.com if any conditions of this licensing are not clear to you.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "paintbufferviewer.h"

#include "ui_paintbufferviewer.h"

#include "widgetinspectorinterface.h"
#include <common/objectbroker.h>

using namespace GammaRay;

PaintBufferViewer::PaintBufferViewer(QWidget *parent)
  : QDialog(parent)
  , ui(new Ui::PaintBufferViewer)
{
  ui->setupUi(this);

  ui->commandView->setModel(ObjectBroker::model(QStringLiteral("com.kdab.GammaRay.PaintBufferModel")));
  ui->commandView->setSelectionModel(ObjectBroker::selectionModel(ui->commandView->model()));

  ui->splitter->setStretchFactor(0, 0);
  ui->splitter->setStretchFactor(1, 1);

  connect(ObjectBroker::object<WidgetInspectorInterface*>(), SIGNAL(paintAnalyzed(QPixmap)),
          ui->replayWidget, SLOT(setPixmap(QPixmap)));
  connect(ui->zoomSlider, SIGNAL(valueChanged(int)), ui->replayWidget, SLOT(setZoomFactor(int)));
}

PaintBufferViewer::~PaintBufferViewer()
{
}
